/*
 * seejpg.c
 *
 * Copyright (C) 1993 Evan Harris
 *
 * Permission is granted to freely redistribute and modify this code,
 * providing the author(s) get credit for having written it.
 */

#include "seejpeg.h"
#include <string.h>
#include <getopt.h>
#include <vga.h>

#define VERSION "seejpeg version 1.2"

int opt_greyscale = 0, opt_quantize = 0, opt_verbose = 0, opt_widthonly = 0;
int opt_onepass = 0, opt_forcemode = TEXT;
double opt_fuzz = 1.0;


int
main(int argc, char **argv)
{
  int c, err = 0;
  
  while ((c = getopt(argc, argv, "1f:gqvwF:")) != -1) {
    switch (c) {
    case '1':
      opt_onepass = 1;
      break;
    case 'f':
      opt_fuzz = atof(optarg);
      if (opt_fuzz < 0.5 || opt_fuzz > 1.0) {
	fprintf(stderr, "Error: fuzz factor must be in range [0.5,1.0]\n");
	exit(1);
      }
      break;
    case 'g':
      opt_greyscale = 1;
      break;
    case 'q':
      opt_quantize = 1;
      break;
    case 'v':
      opt_verbose = 1;
      break;
    case 'w':
      opt_widthonly = 1;
      break;
    case 'F':
      opt_forcemode = vga_getmodenumber(optarg);
      switch (opt_forcemode) {
      case G1280x1024x256:
      case G1024x768x256:
      case G800x600x256:
      case G640x480x256:
      case G320x200x256:
	opt_quantize = 1;
	break;
      case G1280x1024x16M:
      case G1024x768x16M:
      case G800x600x16M:
      case G640x480x16M:
      case G320x200x16M:
      case G1280x1024x32K:
      case G1024x768x32K:
      case G800x600x32K:
      case G640x480x32K:
      case G320x200x32K:
	break;
      default:
	fprintf(stderr, "Error: unknown/unsupported mode name '%s'\n", optarg);
	exit(1);
	break;
      }
      break;
    case '?':
      err++;
      break;
    }
  }
  
  if (err || argc - optind != 1) {
    fprintf(stderr, VERSION"\n");
    fprintf(stderr,
	    "Usage: %s [-1] [-f fuzz] [-g] [-q] [-v] [-w] [-F mode] {file}\n",
	    argv[0]);
    fprintf(stderr, "\t-1  one pass quantization (-q implicit)\n");
    fprintf(stderr, "\t-f  set fuzz factor to determine video mode\n");
    fprintf(stderr, "\t-g  force greyscale mode (-1 implicit)\n");
    fprintf(stderr, "\t-q  quantize picture (256 colour mode)\n");
    fprintf(stderr, "\t-v  verbose\n");
    fprintf(stderr, "\t-w  only use width to determine video mode\n");
    fprintf(stderr, "\t-F  force the use of the given video mode\n");
    fprintf(stderr, "File types supported: JPEG, GIF, PPM, TARGA\n");
    exit(1);
  }

  if (!opt_verbose) {
    vga_disabledriverreport();
  }

  return read_image_file (argv[optind]);
}
